"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.uploadConfig = exports.persistConfig = exports.globalConfig = void 0;
const node_path_1 = require("node:path");
const env_1 = require("./env");
function globalConfig(options, context) {
    const { projectConfig } = context;
    const { root: projectRoot = '' } = projectConfig ?? {};
    // For better debugging use `--verbose --no-progress` as default
    const { verbose, progress, config } = options;
    return {
        verbose: !!verbose,
        progress: !!progress,
        config: config ?? (0, node_path_1.join)(projectRoot, 'code-pushup.config.ts'),
    };
}
exports.globalConfig = globalConfig;
function persistConfig(options, context) {
    const { projectConfig, workspaceRoot } = context;
    const { name: projectName = '' } = projectConfig ?? {};
    const { format, outputDir = (0, node_path_1.join)(workspaceRoot, '.code-pushup', projectName), // always in <root>/.code-pushup/<project-name>,
    filename, } = options;
    return {
        outputDir,
        ...(format ? { format } : {}),
        ...(filename ? { filename } : {}),
    };
}
exports.persistConfig = persistConfig;
function uploadConfig(options, context) {
    const { projectConfig, workspaceRoot } = context;
    const { name: projectName } = projectConfig ?? {};
    const { projectPrefix, server, apiKey, organization, project, timeout } = options;
    const applyPrefix = workspaceRoot === '.';
    const prefix = projectPrefix ? `${projectPrefix}-` : '';
    return {
        ...(projectName
            ? {
                project: applyPrefix ? `${prefix}${projectName}` : projectName,
            }
            : {}),
        ...(0, env_1.parseEnv)(process.env),
        ...Object.fromEntries(Object.entries({ server, apiKey, organization, project, timeout }).filter(([_, v]) => v !== undefined)),
    };
}
exports.uploadConfig = uploadConfig;
//# sourceMappingURL=config.js.map